==> php81-nextcloud-30.0.11.tgz: share/nextcloud/apps/circles/l10n/sq.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Ju fshitë {circle}",
    "{author} deleted {circle}" : "{author} fshiu {circle}",
    "You removed {member} from {circle}" : "Ju hoqët {member} nga {circle}",
    "You joined {circle}" : "Ju iu bashkuat {circle}",
    "{member} joined {circle}" : "{member} iu bashkua {circle}",
    "You accepted the invitation to join {circle}" : "Ju pranuat ftesën për t'u bashkuar {circle}",
    "{member} accepted the invitation to join {circle}" : "{anëtar} pranoi ftesën për tu bashkuar {rreth}",
    "You added {member} as member to {circle}" : "Ju shtuat {member} si anëtar në {circle}",
    "You have been added as member to {circle} by {author}" : "Ju u shtuat si anëtar në {circle} nga {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} u shtua si anëtar në {circle} nga {author}",
    "You added {external} to {circle}" : "Ju shtuat {external} te {circle}",
    "{external} has been added to {circle} by {author}" : "{external} u shtua si anëtar në {circle} nga {author}",
    "You accepted {member}'s request to join {circle}" : "Ju e pranuat {member}'s kërkesën për tu bashkuar {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Kërkesa juaj për tu bashkuar{rreth} është pranuar nga {autor}",
    "You left {circle}" : "Ju latë {circle}",
    "{member} left {circle}" : "{member} la {circle}",
    "You declined the invitation to join {circle}" : "Ju refuzuat ftesën për t'u bashkuar {circle}",
    "{member} declined an invitation to join {circle}" : "{member} refuzoi ftesën për tu bashkuar {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "ju ndryshuat nivelin e {member} në {circle} në %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ndryshoi nivelin tuaj në {circle} në %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ndryshoi nivelin e {member} në {circle} në %1$s",
    "{member} sent a request to join {circle}" : "{member} dërgoi një kërkesë për t'ju bashkuar {circle}",
    "You are the new owner of {circle}" : "Ju jeni pronari i ri i {circle}",
    "{member} is the new owner of {circle}" : "{member} është zoteruesi i ri i {rrethit}",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Visible" : "I dukshëm",
    "Password protected" : "Mbrojtur me fjalëkalim",
    "Hidden" : "I fshehur",
    "Local" : "Lokale",
    "Root" : "Rrënjë",
    "Federated" : "Federated",
    "Contact" : "Kontakt",
    "Circle" : "Rreth",
    "Member" : "Anëtar",
    "Moderator" : "Moderator",
    "Admin" : "Administratori",
    "Owner" : "Zotëruesi",
    "%s shared »%s« with you." : "1 %s ndarë »1 %s« me ju.",
    "%s on %s" : "%s në %s",
    "Password to access »%s«" : "Fjalëkalimi për akses »%s«",
    "Click the button below to open it." : "Kliko butonin më poshtë për të hapur atë.",
    "Open »%s«" : "Hap »%s«",
    "Files" : "Skedarë",
    "This feature is not available for personal circles" : "Ky funksion nuk është i vlefshëm për rrathë personal.",
    "This member is not a moderator" : "Ky anëtar nuk është moderator",
    "This member does not exist" : "Ky anëtar nuk ekziston",
    "You are already a member of this circle" : "Ju jeni tashmë anëtar i këtij rrethi",
    "You have been blocked from this circle" : "Ju jeni bllokuar nga ky rreth",
    "Accept" : "Prano",
    "%s" : "%s",
    "No files in here" : "Jo dosje këtu",
    "No entries found in this folder" : "Në këtë dosje nuk gjëndet asnjë hyrje",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Modifikuar "
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-30.0.15.tgz: share/nextcloud/apps/circles/l10n/sq.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Ju fshitë {circle}",
    "{author} deleted {circle}" : "{author} fshiu {circle}",
    "You removed {member} from {circle}" : "Ju hoqët {member} nga {circle}",
    "You joined {circle}" : "Ju iu bashkuat {circle}",
    "{member} joined {circle}" : "{member} iu bashkua {circle}",
    "You accepted the invitation to join {circle}" : "Ju pranuat ftesën për t'u bashkuar {circle}",
    "{member} accepted the invitation to join {circle}" : "{anëtar} pranoi ftesën për tu bashkuar {rreth}",
    "You added {member} as member to {circle}" : "Ju shtuat {member} si anëtar në {circle}",
    "You have been added as member to {circle} by {author}" : "Ju u shtuat si anëtar në {circle} nga {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} u shtua si anëtar në {circle} nga {author}",
    "You added {external} to {circle}" : "Ju shtuat {external} te {circle}",
    "{external} has been added to {circle} by {author}" : "{external} u shtua si anëtar në {circle} nga {author}",
    "You accepted {member}'s request to join {circle}" : "Ju e pranuat {member}'s kërkesën për tu bashkuar {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Kërkesa juaj për tu bashkuar{rreth} është pranuar nga {autor}",
    "You left {circle}" : "Ju latë {circle}",
    "{member} left {circle}" : "{member} la {circle}",
    "You declined the invitation to join {circle}" : "Ju refuzuat ftesën për t'u bashkuar {circle}",
    "{member} declined an invitation to join {circle}" : "{member} refuzoi ftesën për tu bashkuar {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "ju ndryshuat nivelin e {member} në {circle} në %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ndryshoi nivelin tuaj në {circle} në %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ndryshoi nivelin e {member} në {circle} në %1$s",
    "{member} sent a request to join {circle}" : "{member} dërgoi një kërkesë për t'ju bashkuar {circle}",
    "You are the new owner of {circle}" : "Ju jeni pronari i ri i {circle}",
    "{member} is the new owner of {circle}" : "{member} është zoteruesi i ri i {rrethit}",
    "Personal" : "Personale",
    "System" : "Sistem",
    "Visible" : "I dukshëm",
    "Password protected" : "Mbrojtur me fjalëkalim",
    "Hidden" : "I fshehur",
    "Local" : "Lokale",
    "Root" : "Rrënjë",
    "Federated" : "Federated",
    "Contact" : "Kontakt",
    "Member" : "Anëtar",
    "Moderator" : "Moderator",
    "Admin" : "Administratori",
    "Owner" : "Zotëruesi",
    "%s shared »%s« with you." : "1 %s ndarë »1 %s« me ju.",
    "%s on %s" : "%s në %s",
    "Password to access »%s«" : "Fjalëkalimi për akses »%s«",
    "Click the button below to open it." : "Kliko butonin më poshtë për të hapur atë.",
    "Open »%s«" : "Hap »%s«",
    "Files" : "Skedarë",
    "This feature is not available for personal circles" : "Ky funksion nuk është i vlefshëm për rrathë personal.",
    "This member is not a moderator" : "Ky anëtar nuk është moderator",
    "This member does not exist" : "Ky anëtar nuk ekziston",
    "You are already a member of this circle" : "Ju jeni tashmë anëtar i këtij rrethi",
    "You have been blocked from this circle" : "Ju jeni bllokuar nga ky rreth",
    "Accept" : "Prano",
    "%s" : "%s",
    "Open %s" : "Hap %s",
    "Try again" : "Provo përsëri",
    "Loading…" : "Duke u ngarkuar…",
    "No files in here" : "Jo dosje këtu",
    "No entries found in this folder" : "Në këtë dosje nuk gjëndet asnjë hyrje",
    "Name" : "Emër",
    "Size" : "Madhësi",
    "Modified" : "Modifikuar ",
    "Circle" : "Rreth"
},
"nplurals=2; plural=(n != 1);");
